
/*
 * Copyright (C) 2002-2003 Stefan Holst
 *
 * This file is part of oxine a free media player.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * $Id: odk_joystick.h 2650 2007-08-21 13:57:50Z mschwerin $
 *
 */

#ifndef HAVE_ODK_JOYSTICK_H
#define HAVE_ODK_JOYSTICK_H

#ifdef HAVE_JOYSTICK

#include "odk.h"

odk_input_t *start_joystick (odk_t * odk, event_handler_t event_handler);
void stop_joystick (odk_input_t * oi);

#endif /* HAVE_JOYSTICK */
#endif /* HAVE_ODK_JOYSTICK_H */
